Index: main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/contracts.py
===================================================================
--- main/ikobacustom.pcn/trunk/src/ikobacustom/skeleton/customers/contracts.py	(revision 12370)
+++ main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/contracts.py	(revision 12371)
@@ -26,42 +26,42 @@
 from waeup.ikoba.customers.interfaces import ICustomerNavigation
 from waeup.ikoba.customers.contracts import ContractBase
-from ikobacustom.skeleton.interfaces import MessageFactory as _
-from ikobacustom.skeleton.customers.interfaces import (
-    ISkeletonContract, ISkeletonContractEdit, ISkeletonContractProcess)
+from ikobacustom.pcn.interfaces import MessageFactory as _
+from ikobacustom.pcn.customers.interfaces import (
+    IPCNContract, IPCNContractEdit, IPCNContractProcess)
 
 
-class SkeletonContract(ContractBase):
+class PCNContract(ContractBase):
     """This is a sample contract.
     """
 
     grok.implements(
-        ISkeletonContractProcess,
-        ISkeletonContract,
-        ISkeletonContractEdit,
+        IPCNContractProcess,
+        IPCNContract,
+        IPCNContractEdit,
         ICustomerNavigation)
 
     contract_category = 'sample'
 
-    form_fields_interface = ISkeletonContract
+    form_fields_interface = IPCNContract
 
-    edit_form_fields_interface = ISkeletonContractEdit
+    edit_form_fields_interface = IPCNContractEdit
 
-    check_docs_interface = ISkeletonContract
+    check_docs_interface = IPCNContract
 
-SkeletonContract = attrs_to_fields(SkeletonContract)
+PCNContract = attrs_to_fields(PCNContract)
 
 
 # Contracts must be importable. So we might need a factory.
-class SkeletonContractFactory(grok.GlobalUtility):
+class PCNContractFactory(grok.GlobalUtility):
     """A factory for contracts.
     """
     grok.implements(IFactory)
-    grok.name(u'waeup.SkeletonContract')
+    grok.name(u'waeup.PCNContract')
     title = u"Create a new contract.",
     description = u"This factory instantiates new sample contract instances."
 
     def __call__(self, *args, **kw):
-        return SkeletonContract(*args, **kw)
+        return PCNContract(*args, **kw)
 
     def getInterfaces(self):
-        return implementedBy(SkeletonContract)
+        return implementedBy(PCNContract)
Index: main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/customer.py
===================================================================
--- main/ikobacustom.pcn/trunk/src/ikobacustom/skeleton/customers/customer.py	(revision 12370)
+++ main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/customer.py	(revision 12371)
@@ -25,29 +25,29 @@
 from waeup.ikoba.customers.customer import Customer
 from waeup.ikoba.customers.interfaces import ICustomerNavigation
-from ikobacustom.skeleton.customers.interfaces import ISkeletonCustomer
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.pcn.customers.interfaces import IPCNCustomer
+from ikobacustom.pcn.interfaces import MessageFactory as _
 
 
-class SkeletonCustomer(Customer):
+class PCNCustomer(Customer):
     """This is a customer container for the various objects
     owned by customers.
     """
-    grok.implements(ISkeletonCustomer, ICustomerNavigation)
-    grok.provides(ISkeletonCustomer)
+    grok.implements(IPCNCustomer, ICustomerNavigation)
+    grok.provides(IPCNCustomer)
 
-SkeletonCustomer = attrs_to_fields(SkeletonCustomer)
+PCNCustomer = attrs_to_fields(PCNCustomer)
 
 
-class SkeletonCustomerFactory(grok.GlobalUtility):
+class PCNCustomerFactory(grok.GlobalUtility):
     """A factory for customers.
     """
     grok.implements(IFactory)
     grok.name(u'waeup.Customer')
-    title = u"Create a new skeleton customer.",
-    description = u"This factory instantiates new skeleton customer instances."
+    title = u"Create a new pcn customer.",
+    description = u"This factory instantiates new pcn customer instances."
 
     def __call__(self, *args, **kw):
-        return SkeletonCustomer()
+        return PCNCustomer()
 
     def getInterfaces(self):
-        return implementedBy(SkeletonCustomer)
+        return implementedBy(PCNCustomer)
Index: main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/documents.py
===================================================================
--- main/ikobacustom.pcn/trunk/src/ikobacustom/skeleton/customers/documents.py	(revision 12370)
+++ main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/documents.py	(revision 12371)
@@ -25,14 +25,14 @@
 from waeup.ikoba.customers.interfaces import ICustomerNavigation
 from waeup.ikoba.customers.documents import CustomerDocumentBase
-from ikobacustom.skeleton.interfaces import MessageFactory as _
-from ikobacustom.skeleton.customers.interfaces import ISkeletonCustomerDocument
+from ikobacustom.pcn.interfaces import MessageFactory as _
+from ikobacustom.pcn.customers.interfaces import IPCNCustomerDocument
 
 
-class SkeletonCustomerDocument(CustomerDocumentBase):
+class PCNCustomerDocument(CustomerDocumentBase):
     """This is a sample customer document.
     """
 
-    grok.implements(ISkeletonCustomerDocument, ICustomerNavigation)
-    grok.provides(ISkeletonCustomerDocument)
+    grok.implements(IPCNCustomerDocument, ICustomerNavigation)
+    grok.provides(IPCNCustomerDocument)
 
     # Ikoba can store any number of files per Document object.
@@ -42,21 +42,21 @@
     filenames = ('sample',)
 
-    form_fields_interface = ISkeletonCustomerDocument
+    form_fields_interface = IPCNCustomerDocument
 
-SkeletonCustomerDocument = attrs_to_fields(SkeletonCustomerDocument)
+PCNCustomerDocument = attrs_to_fields(PCNCustomerDocument)
 
 
 # Customer documents must be importable. So we need a factory.
-class SkeletonCustomerDocumentFactory(grok.GlobalUtility):
+class PCNCustomerDocumentFactory(grok.GlobalUtility):
     """A factory for customer documents.
     """
     grok.implements(IFactory)
-    grok.name(u'waeup.SkeletonCustomerDocument')
+    grok.name(u'waeup.PCNCustomerDocument')
     title = u"Create a new document.",
     description = u"This factory instantiates new sample document instances."
 
     def __call__(self, *args, **kw):
-        return SkeletonCustomerDocument(*args, **kw)
+        return PCNCustomerDocument(*args, **kw)
 
     def getInterfaces(self):
-        return implementedBy(SkeletonCustomerDocument)
+        return implementedBy(PCNCustomerDocument)
Index: main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/fileviewlets.py
===================================================================
--- main/ikobacustom.pcn/trunk/src/ikobacustom/skeleton/customers/fileviewlets.py	(revision 12370)
+++ main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/fileviewlets.py	(revision 12371)
@@ -23,5 +23,5 @@
     FileDisplay, FileUpload, Image)
 
-from ikobacustom.skeleton.customers.documents import SkeletonCustomerDocument
+from ikobacustom.pcn.customers.documents import PCNCustomerDocument
 
 from waeup.ikoba.customers.browser import (
@@ -39,5 +39,5 @@
     """
     grok.order(1)
-    grok.context(SkeletonCustomerDocument)
+    grok.context(PCNCustomerDocument)
     grok.view(DocumentManageFormPage)
     grok.require('waeup.manageCustomer')
@@ -60,5 +60,5 @@
     """
     grok.order(1)
-    grok.context(SkeletonCustomerDocument)
+    grok.context(PCNCustomerDocument)
     grok.require('waeup.viewCustomer')
     grok.view(DocumentDisplayFormPage)
@@ -72,5 +72,5 @@
     """
     grok.name('sample')
-    grok.context(SkeletonCustomerDocument)
+    grok.context(PCNCustomerDocument)
     grok.require('waeup.viewCustomer')
     download_name = u'sample'
@@ -84,5 +84,5 @@
     """
     grok.view(DocumentManageFormPage)
-    grok.context(SkeletonCustomerDocument)
+    grok.context(PCNCustomerDocument)
     grok.require('waeup.manageCustomer')
     label = _(u'PDF File')
@@ -104,5 +104,5 @@
     """
     grok.order(1)
-    grok.context(SkeletonCustomerDocument)
+    grok.context(PCNCustomerDocument)
     grok.require('waeup.viewCustomer')
     grok.view(DocumentDisplayFormPage)
@@ -116,5 +116,5 @@
     """
     grok.name('sample.pdf')
-    grok.context(SkeletonCustomerDocument)
+    grok.context(PCNCustomerDocument)
     grok.require('waeup.viewCustomer')
     download_name = u'sample.pdf'
Index: main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/interfaces.py
===================================================================
--- main/ikobacustom.pcn/trunk/src/ikobacustom/skeleton/customers/interfaces.py	(revision 12370)
+++ main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/interfaces.py	(revision 12371)
@@ -23,8 +23,8 @@
     ConCatProductSource, CustomerDocumentSource)
 from waeup.ikoba.products.productoptions import ProductOptionField
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.pcn.interfaces import MessageFactory as _
 
 
-class ISkeletonCustomer(ICustomer):
+class IPCNCustomer(ICustomer):
     """Representation of a customer.
 
@@ -34,5 +34,5 @@
 
 
-class ISkeletonCustomerDocument(ICustomerDocument):
+class IPCNCustomerDocument(ICustomerDocument):
     """A customer document.
 
@@ -41,5 +41,5 @@
 # Customer contract interfaces
 
-class ISkeletonContract(IContract):
+class IPCNContract(IContract):
     """A customer contract sample with document attached.
 
@@ -52,5 +52,5 @@
         )
 
-class ISkeletonContractProcess(ISkeletonContract):
+class IPCNContractProcess(IPCNContract):
     """Interface for processing contract data.
     """
@@ -64,5 +64,5 @@
         )
 
-class ISkeletonContractEdit(ISkeletonContract):
+class IPCNContractEdit(IPCNContract):
     """Interface for editing sample contract data by customers.
 
Index: main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/tests/test_browser.py
===================================================================
--- main/ikobacustom.pcn/trunk/src/ikobacustom/skeleton/customers/tests/test_browser.py	(revision 12370)
+++ main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/tests/test_browser.py	(revision 12371)
@@ -30,13 +30,13 @@
 from waeup.ikoba.customers.tests.test_batching import CustomerImportExportSetup
 from waeup.ikoba.customers.tests.test_browser import CustomersFullSetup
-from ikobacustom.skeleton.customers.export import (
-    SkeletonCustomerExporter,
-    SkeletonCustomerDocumentExporter,
-    SkeletonContractExporter)
-from ikobacustom.skeleton.customers.batching import (
-    SkeletonCustomerProcessor,
-    SkeletonCustomerDocumentProcessor,
-    SkeletonContractProcessor)
-from ikobacustom.skeleton.testing import FunctionalLayer, samples_dir
+from ikobacustom.pcn.customers.export import (
+    PCNCustomerExporter,
+    PCNCustomerDocumentExporter,
+    PCNContractExporter)
+from ikobacustom.pcn.customers.batching import (
+    PCNCustomerProcessor,
+    PCNCustomerDocumentProcessor,
+    PCNContractProcessor)
+from ikobacustom.pcn.testing import FunctionalLayer, samples_dir
 
 SAMPLE_IMAGE = os.path.join(os.path.dirname(__file__), 'test_image.jpg')
@@ -56,8 +56,8 @@
         IWorkflowState(customer).setState('started')
         self.app['customers'].addCustomer(customer)
-        document = createObject(u'waeup.SkeletonCustomerDocument')
+        document = createObject(u'waeup.PCNCustomerDocument')
         document.title = u'My first document'
         customer['documents'].addDocument(document)
-        contract = createObject(u'waeup.SkeletonContract')
+        contract = createObject(u'waeup.PCNContract')
         contract.tc_dict = {'en':u'Hello World'}
         customer['contracts'].addContract(contract)
@@ -72,5 +72,5 @@
         # set values we can expect in export file
         self.setup_for_export()
-        exporter = SkeletonCustomerExporter()
+        exporter = PCNCustomerExporter()
         exporter.export_all(self.app, self.outfile)
         result = open(self.outfile, 'rb').read()
@@ -80,5 +80,5 @@
             'K1000000,,Beate,Mueller,,,123,f,0,,,started,[]\r\n')
         # We can reimport the file ...
-        processor = SkeletonCustomerProcessor()
+        processor = PCNCustomerProcessor()
         result = processor.doImport(
             self.outfile,
@@ -112,18 +112,18 @@
         # set values we can expect in export file
         self.setup_for_export()
-        exporter = SkeletonCustomerDocumentExporter()
+        exporter = PCNCustomerDocumentExporter()
         exporter.export_all(self.app, self.outfile)
         result = open(self.outfile, 'rb').read()
         self.assertMatches(result,
             'class_name,document_id,history,state,title,user_id\r\n'
-            'SkeletonCustomerDocument,%s,'
+            'PCNCustomerDocument,%s,'
             '[u\'2014-12-21 17:00:36 WAT - Document created by system\'],'
             'created,My first document,K1000000\r\n'
             % self.document.document_id)
         # We can reimport the file if we change the header (user_id -> customer_id)
-        processor = SkeletonCustomerDocumentProcessor()
+        processor = PCNCustomerDocumentProcessor()
         open(self.outfile, 'wb').write(
             'customer_id,class_name,document_id,state,title\r\n'
-            'K1000000,SkeletonCustomerDocument,%s,started,My first title\r\n'
+            'K1000000,PCNCustomerDocument,%s,started,My first title\r\n'
             % self.document.document_id)
         result = processor.doImport(
@@ -156,5 +156,5 @@
         # set values we can expect in export file
         self.setup_for_export()
-        exporter = SkeletonContractExporter()
+        exporter = PCNContractExporter()
         exporter.export_all(self.app, self.outfile)
         result = open(self.outfile, 'rb').read()
@@ -163,15 +163,15 @@
             'history,last_product_id,product_object,product_options,'
             'state,tc_dict,title,user_id\r\n'
-            'SkeletonContract,sample,%s,,'
+            'PCNContract,sample,%s,,'
             '[u\'2014-12-21 22:26:00 WAT - Contract created by system\']'
             ',,,[],created,{\'en\': u\'Hello World\'},,K1000000\r\n'
             % self.contract.contract_id)
         # We can reimport the file if we change the header (user_id -> customer_id)
-        processor = SkeletonContractProcessor()
+        processor = PCNContractProcessor()
         open(self.outfile, 'wb').write(
             'class_name,contract_category,contract_id,document_object,'
             'history,last_product_id,product_object,product_options,'
             'state,tc_dict,title,user_id\r\n'
-            'SkeletonContract,sample,%s,,'
+            'PCNContract,sample,%s,,'
             '[u\'2014-12-21 22:26:00 WAT - Contract created by system\']'
             ',,,[],created,{\'en\': u\'Hello World\'},,K1000000\r\n'
@@ -219,6 +219,6 @@
         self.browser.open(self.customer_path + '/documents')
         self.browser.getControl("Add document").click()
-        self.browser.getControl(name="doctype").value = ['SkeletonCustomerDocument']
-        self.browser.getControl(name="form.title").value = 'My Skeleton Document'
+        self.browser.getControl(name="doctype").value = ['PCNCustomerDocument']
+        self.browser.getControl(name="form.title").value = 'My PCN Document'
         self.browser.getControl("Add document").click()
         docid = [i for i in self.customer['documents'].keys() if len(i) > 10][0]
Index: main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/tests/test_contract.py
===================================================================
--- main/ikobacustom.pcn/trunk/src/ikobacustom/skeleton/customers/tests/test_contract.py	(revision 12370)
+++ main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/tests/test_contract.py	(revision 12371)
@@ -28,7 +28,7 @@
 from waeup.ikoba.customers.contracts import ContractsContainer
 
-from ikobacustom.skeleton.testing import (FunctionalLayer, FunctionalTestCase)
-from ikobacustom.skeleton.customers.contracts import SkeletonContract
-from ikobacustom.skeleton.customers.interfaces import ISkeletonContract
+from ikobacustom.pcn.testing import (FunctionalLayer, FunctionalTestCase)
+from ikobacustom.pcn.customers.contracts import PCNContract
+from ikobacustom.pcn.customers.interfaces import IPCNContract
 
 
@@ -38,17 +38,17 @@
 
     def test_interfaces(self):
-        verify.verifyClass(ISkeletonContract, SkeletonContract)
-        verify.verifyClass(ICustomerNavigation, SkeletonContract)
-        verify.verifyObject(ISkeletonContract, SkeletonContract())
-        verify.verifyObject(ICustomerNavigation, SkeletonContract())
+        verify.verifyClass(IPCNContract, PCNContract)
+        verify.verifyClass(ICustomerNavigation, PCNContract)
+        verify.verifyObject(IPCNContract, PCNContract())
+        verify.verifyObject(ICustomerNavigation, PCNContract())
         return
 
     def test_addContract(self):
         container = ContractsContainer()
-        contract = createObject(u'waeup.SkeletonContract')
+        contract = createObject(u'waeup.PCNContract')
         id = contract.contract_id
         container.addContract(contract)
         self.assertEqual(container[id], contract)
         self.assertRaises(TypeError, container.addContract, object())
-        self.assertEqual(contract.class_name, 'SkeletonContract')
+        self.assertEqual(contract.class_name, 'PCNContract')
         return
Index: main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/tests/test_customer.py
===================================================================
--- main/ikobacustom.pcn/trunk/src/ikobacustom/skeleton/customers/tests/test_customer.py	(revision 12370)
+++ main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/tests/test_customer.py	(revision 12371)
@@ -17,5 +17,5 @@
 ##
 """
-Tests for skeleton customers.
+Tests for pcn customers.
 """
 import tempfile
@@ -30,14 +30,14 @@
 from waeup.ikoba.customers.container import CustomersContainer
 
-from ikobacustom.skeleton.testing import (FunctionalLayer, FunctionalTestCase)
-from ikobacustom.skeleton.customers.customer import SkeletonCustomer
-from ikobacustom.skeleton.customers.interfaces import ISkeletonCustomer
+from ikobacustom.pcn.testing import (FunctionalLayer, FunctionalTestCase)
+from ikobacustom.pcn.customers.customer import PCNCustomer
+from ikobacustom.pcn.customers.interfaces import IPCNCustomer
 
-class SkeletonCustomerTestCase(FunctionalTestCase):
+class PCNCustomerTestCase(FunctionalTestCase):
 
     layer = FunctionalLayer
 
     def setUp(self):
-        super(SkeletonCustomerTestCase, self).setUp()
+        super(PCNCustomerTestCase, self).setUp()
 
         # Prepopulate ZODB
@@ -52,13 +52,13 @@
 
     def test_interfaces(self):
-        verify.verifyClass(ISkeletonCustomer, SkeletonCustomer)
-        verify.verifyClass(ICustomerNavigation, SkeletonCustomer)
-        verify.verifyObject(ISkeletonCustomer, SkeletonCustomer())
-        verify.verifyObject(ICustomerNavigation, SkeletonCustomer())
+        verify.verifyClass(IPCNCustomer, PCNCustomer)
+        verify.verifyClass(ICustomerNavigation, PCNCustomer)
+        verify.verifyObject(IPCNCustomer, PCNCustomer())
+        verify.verifyObject(ICustomerNavigation, PCNCustomer())
         return
 
-    def test_addSkeletonCustomer(self):
+    def test_addPCNCustomer(self):
         customer = createObject(u'waeup.Customer')
-        verify.verifyObject(ISkeletonCustomer, customer)
+        verify.verifyObject(IPCNCustomer, customer)
         self.app['customers'].addCustomer(customer)
         self.assertEqual(customer.customer_id, 'K1000000')
@@ -68,4 +68,4 @@
     def tearDown(self):
         shutil.rmtree(self.dc_root)
-        super(SkeletonCustomerTestCase, self).tearDown()
+        super(PCNCustomerTestCase, self).tearDown()
         return
Index: main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/tests/test_document.py
===================================================================
--- main/ikobacustom.pcn/trunk/src/ikobacustom/skeleton/customers/tests/test_document.py	(revision 12370)
+++ main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/tests/test_document.py	(revision 12371)
@@ -28,7 +28,7 @@
 from waeup.ikoba.customers.documents import CustomerDocumentsContainer
 
-from ikobacustom.skeleton.testing import (FunctionalLayer, FunctionalTestCase)
-from ikobacustom.skeleton.customers.documents import SkeletonCustomerDocument
-from ikobacustom.skeleton.customers.interfaces import ISkeletonCustomerDocument
+from ikobacustom.pcn.testing import (FunctionalLayer, FunctionalTestCase)
+from ikobacustom.pcn.customers.documents import PCNCustomerDocument
+from ikobacustom.pcn.customers.interfaces import IPCNCustomerDocument
 
 
@@ -38,17 +38,17 @@
 
     def test_interfaces(self):
-        verify.verifyClass(ISkeletonCustomerDocument, SkeletonCustomerDocument)
-        verify.verifyClass(ICustomerNavigation, SkeletonCustomerDocument)
-        verify.verifyObject(ISkeletonCustomerDocument, SkeletonCustomerDocument())
-        verify.verifyObject(ICustomerNavigation, SkeletonCustomerDocument())
+        verify.verifyClass(IPCNCustomerDocument, PCNCustomerDocument)
+        verify.verifyClass(ICustomerNavigation, PCNCustomerDocument)
+        verify.verifyObject(IPCNCustomerDocument, PCNCustomerDocument())
+        verify.verifyObject(ICustomerNavigation, PCNCustomerDocument())
         return
 
     def test_addDocument(self):
         container = CustomerDocumentsContainer()
-        document = createObject(u'waeup.SkeletonCustomerDocument')
+        document = createObject(u'waeup.PCNCustomerDocument')
         id = document.document_id
         container.addDocument(document)
         self.assertEqual(container[id], document)
         self.assertRaises(TypeError, container.addDocument, object())
-        self.assertEqual(document.class_name, 'SkeletonCustomerDocument')
+        self.assertEqual(document.class_name, 'PCNCustomerDocument')
         return
Index: main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/utils.py
===================================================================
--- main/ikobacustom.pcn/trunk/src/ikobacustom/skeleton/customers/utils.py	(revision 12370)
+++ main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/utils.py	(revision 12371)
@@ -25,7 +25,7 @@
     SUBMITTED, VERIFIED, REJECTED,
     EXPIRED)
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.pcn.interfaces import MessageFactory as _
 
-class SkeletonCustomersUtils(CustomersUtils):
+class PCNCustomersUtils(CustomersUtils):
     """A collection of methods subject to customization.
     """
@@ -47,5 +47,5 @@
         #'CustomerPDFDocument': _('PDF Document'),
 
-        'SkeletonCustomerDocument': _('Skeleton Document'),
+        'PCNCustomerDocument': _('PCN Document'),
         }
 
@@ -53,5 +53,5 @@
         #'SampleContract': _('Sample Contract'),
 
-        'SkeletonContract': _('Skeleton Contract'),
+        'PCNContract': _('PCN Contract'),
         }
 
@@ -62,4 +62,4 @@
     EXPORTER_NAMES = (
         'customers',
-        'skeletoncustomerdocuments',
-        'skeletoncontracts')
+        'pcncustomerdocuments',
+        'pcncontracts')

Index: main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/batching.py
===================================================================
--- main/ikobacustom.pcn/trunk/src/ikobacustom/skeleton/customers/batching.py	(revision 12370)
+++ main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/batching.py	(revision 12371)
@@ -16,5 +16,5 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
 """Batch processing for skeleton documents.
 """
 import grok
@@ -22,35 +22,35 @@
     CustomerProcessor,
     CustomerDocumentProcessorBase, ContractProcessorBase)
-from ikobacustom.skeleton.customers.interfaces import (
-    ISkeletonCustomer,
-    ISkeletonCustomerDocument, ISkeletonContract)
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.pcn.customers.interfaces import (
+    IPCNCustomer,
+    IPCNCustomerDocument, IPCNContract)
+from ikobacustom.pcn.interfaces import MessageFactory as _
 
 
-class SkeletonCustomerProcessor(CustomerProcessor):
+class PCNCustomerProcessor(CustomerProcessor):
     """A batch processor for ICustomer objects.
     """
-    util_name = 'skeletoncustomerprocessor'
+    util_name = 'pcncustomerprocessor'
     grok.name(util_name)
-    name = _('Skeleton Customer Processor')
-    iface = ISkeletonCustomer
+    name = _('PCN Customer Processor')
+    iface = IPCNCustomer
 
 
-class SkeletonCustomerDocumentProcessor(CustomerDocumentProcessorBase):
-    """A batch processor for ISkeletonCustomerDocument objects.
+class PCNCustomerDocumentProcessor(CustomerDocumentProcessorBase):
+    """A batch processor for IPCNCustomerDocument objects.
     """
-    util_name = 'skeletoncustomerdocumentprocessor'
+    util_name = 'pcncustomerdocumentprocessor'
     grok.name(util_name)
-    name = _('Skeleton Customer Document Processor')
-    iface = ISkeletonCustomerDocument
-    factory_name = 'waeup.SkeletonCustomerDocument'
+    name = _('PCN Customer Document Processor')
+    iface = IPCNCustomerDocument
+    factory_name = 'waeup.PCNCustomerDocument'
 
 
-class SkeletonContractProcessor(ContractProcessorBase):
-    """A batch processor for ISkeletonContract objects.
+class PCNContractProcessor(ContractProcessorBase):
+    """A batch processor for IPCNContract objects.
     """
-    util_name = 'skeletoncontractprocessor'
+    util_name = 'pcncontractprocessor'
     grok.name(util_name)
-    name = _('Skeleton Customer Contract Processor')
-    iface = ISkeletonContract
-    factory_name = 'waeup.SkeletonContract'
+    name = _('PCN Customer Contract Processor')
+    iface = IPCNContract
+    factory_name = 'waeup.PCNContract'
@@ -16,5 +16,5 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""Batch processing for skeleton documents.
+"""Batch processing for pcn documents.
 """
 import grok
Index: main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/export.py
===================================================================
--- main/ikobacustom.pcn/trunk/src/ikobacustom/skeleton/customers/export.py	(revision 12370)
+++ main/ikobacustom.pcn/trunk/src/ikobacustom/pcn/customers/export.py	(revision 12371)
@@ -16,34 +16,34 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
 """Exporters for skeleton customer objects and subobjects.
 """
 import grok
 from waeup.ikoba.customers.export import (
     CustomerExporter, CustomerDocumentExporterBase, ContractExporterBase)
-from ikobacustom.skeleton.customers.interfaces import (
-    ISkeletonCustomer, ISkeletonCustomerDocument, ISkeletonContract)
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.pcn.customers.interfaces import (
+    IPCNCustomer, IPCNCustomerDocument, IPCNContract)
+from ikobacustom.pcn.interfaces import MessageFactory as _
 
-class SkeletonCustomerExporter(CustomerExporter):
+class PCNCustomerExporter(CustomerExporter):
     """Exporter for Customers.
     """
-    iface = ISkeletonCustomer
-    title = _(u'Skeleton Customers')
+    iface = IPCNCustomer
+    title = _(u'PCN Customers')
 
 
-class SkeletonCustomerDocumentExporter(CustomerDocumentExporterBase):
+class PCNCustomerDocumentExporter(CustomerDocumentExporterBase):
     """Exporter for documents.
     """
-    grok.name('skeletoncustomerdocuments')
-    iface = ISkeletonCustomerDocument
-    title = _(u'Skeleton Customer Documents')
-    class_name = 'SkeletonCustomerDocument'
+    grok.name('pcncustomerdocuments')
+    iface = IPCNCustomerDocument
+    title = _(u'PCN Customer Documents')
+    class_name = 'PCNCustomerDocument'
 
 
-class SkeletonContractExporter(ContractExporterBase):
+class PCNContractExporter(ContractExporterBase):
     """Exporter for Contract instances.
     """
-    grok.name('skeletoncontracts')
-    iface = ISkeletonContract
-    title = _(u'Skeleton Customer Contracts')
-    class_name = 'SkeletonContract'
+    grok.name('pcncontracts')
+    iface = IPCNContract
+    title = _(u'PCN Customer Contracts')
+    class_name = 'PCNContract'
@@ -16,34 +16,34 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""Exporters for skeleton customer objects and subobjects.
+"""Exporters for pcn customer objects and subobjects.
 """
 import grok